# import classes and functions of submodules

__version__ = '2.10.0'



########################## BELOW ARE AUTO-GENERATED ##########################
from tflite.ATan2Options import *
from tflite.AbsOptions import *
from tflite.ActivationFunctionType import *
from tflite.AddNOptions import *
from tflite.AddOptions import *
from tflite.ArgMaxOptions import *
from tflite.ArgMinOptions import *
from tflite.AssignVariableOptions import *
from tflite.BatchMatMulOptions import *
from tflite.BatchToSpaceNDOptions import *
from tflite.BidirectionalSequenceLSTMOptions import *
from tflite.BidirectionalSequenceRNNOptions import *
from tflite.BroadcastToOptions import *
from tflite.BucketizeOptions import *
from tflite.Buffer import *
from tflite.BuiltinOperator import *
from tflite.BuiltinOptions import *
from tflite.CallOnceOptions import *
from tflite.CallOptions import *
from tflite.CastOptions import *
from tflite.CombinerType import *
from tflite.ConcatEmbeddingsOptions import *
from tflite.ConcatenationOptions import *
from tflite.Conv2DOptions import *
from tflite.Conv3DOptions import *
from tflite.CosOptions import *
from tflite.CumsumOptions import *
from tflite.CustomOptionsFormat import *
from tflite.CustomQuantization import *
from tflite.DensifyOptions import *
from tflite.DepthToSpaceOptions import *
from tflite.DepthwiseConv2DOptions import *
from tflite.DequantizeOptions import *
from tflite.DimensionMetadata import *
from tflite.DimensionType import *
from tflite.DivOptions import *
from tflite.DynamicUpdateSliceOptions import *
from tflite.EmbeddingLookupSparseOptions import *
from tflite.EqualOptions import *
from tflite.ExpOptions import *
from tflite.ExpandDimsOptions import *
from tflite.FakeQuantOptions import *
from tflite.FillOptions import *
from tflite.FloorDivOptions import *
from tflite.FloorModOptions import *
from tflite.FullyConnectedOptions import *
from tflite.FullyConnectedOptionsWeightsFormat import *
from tflite.GatherNdOptions import *
from tflite.GatherOptions import *
from tflite.GeluOptions import *
from tflite.GreaterEqualOptions import *
from tflite.GreaterOptions import *
from tflite.HardSwishOptions import *
from tflite.HashtableFindOptions import *
from tflite.HashtableImportOptions import *
from tflite.HashtableOptions import *
from tflite.HashtableSizeOptions import *
from tflite.IfOptions import *
from tflite.Int32Vector import *
from tflite.L2NormOptions import *
from tflite.LSHProjectionOptions import *
from tflite.LSHProjectionType import *
from tflite.LSTMKernelType import *
from tflite.LSTMOptions import *
from tflite.LeakyReluOptions import *
from tflite.LessEqualOptions import *
from tflite.LessOptions import *
from tflite.LocalResponseNormalizationOptions import *
from tflite.LogSoftmaxOptions import *
from tflite.LogicalAndOptions import *
from tflite.LogicalNotOptions import *
from tflite.LogicalOrOptions import *
from tflite.MatrixDiagOptions import *
from tflite.MatrixSetDiagOptions import *
from tflite.MaximumMinimumOptions import *
from tflite.Metadata import *
from tflite.MirrorPadMode import *
from tflite.MirrorPadOptions import *
from tflite.Model import *
from tflite.MulOptions import *
from tflite.NegOptions import *
from tflite.NonMaxSuppressionV4Options import *
from tflite.NonMaxSuppressionV5Options import *
from tflite.NotEqualOptions import *
from tflite.OneHotOptions import *
from tflite.Operator import *
from tflite.OperatorCode import *
from tflite.PackOptions import *
from tflite.PadOptions import *
from tflite.PadV2Options import *
from tflite.Padding import *
from tflite.Pool2DOptions import *
from tflite.PowOptions import *
from tflite.QuantizationDetails import *
from tflite.QuantizationParameters import *
from tflite.QuantizeOptions import *
from tflite.RNNOptions import *
from tflite.RandomOptions import *
from tflite.RangeOptions import *
from tflite.RankOptions import *
from tflite.ReadVariableOptions import *
from tflite.ReducerOptions import *
from tflite.ReshapeOptions import *
from tflite.ResizeBilinearOptions import *
from tflite.ResizeNearestNeighborOptions import *
from tflite.ReverseSequenceOptions import *
from tflite.ReverseV2Options import *
from tflite.Rfft2dOptions import *
from tflite.SVDFOptions import *
from tflite.ScatterNdOptions import *
from tflite.SegmentSumOptions import *
from tflite.SelectOptions import *
from tflite.SelectV2Options import *
from tflite.SequenceRNNOptions import *
from tflite.ShapeOptions import *
from tflite.SignatureDef import *
from tflite.SkipGramOptions import *
from tflite.SliceOptions import *
from tflite.SoftmaxOptions import *
from tflite.SpaceToBatchNDOptions import *
from tflite.SpaceToDepthOptions import *
from tflite.SparseIndexVector import *
from tflite.SparseToDenseOptions import *
from tflite.SparsityParameters import *
from tflite.SplitOptions import *
from tflite.SplitVOptions import *
from tflite.SquareOptions import *
from tflite.SquaredDifferenceOptions import *
from tflite.SqueezeOptions import *
from tflite.StridedSliceOptions import *
from tflite.SubGraph import *
from tflite.SubOptions import *
from tflite.Tensor import *
from tflite.TensorMap import *
from tflite.TensorType import *
from tflite.TileOptions import *
from tflite.TopKV2Options import *
from tflite.TransposeConvOptions import *
from tflite.TransposeOptions import *
from tflite.Uint16Vector import *
from tflite.Uint8Vector import *
from tflite.UnidirectionalSequenceLSTMOptions import *
from tflite.UniqueOptions import *
from tflite.UnpackOptions import *
from tflite.UnsortedSegmentMaxOptions import *
from tflite.UnsortedSegmentProdOptions import *
from tflite.UnsortedSegmentSumOptions import *
from tflite.VarHandleOptions import *
from tflite.WhereOptions import *
from tflite.WhileOptions import *
from tflite.ZerosLikeOptions import *
from tflite.utils import *
########################## ABOVE ARE AUTO-GENERATED ##########################
